summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--test/src/alloc-tests.el2
-rw-r--r--test/src/decompress-tests.el6
2 files changed, 4 insertions, 4 deletions
diff --git a/test/src/alloc-tests.el b/test/src/alloc-tests.el
index 218df05e426..c0fe0f33cb9 100644
--- a/test/src/alloc-tests.el
+++ b/test/src/alloc-tests.el
@@ -1,4 +1,4 @@
-;;; finalizer-tests.el --- Finalizer tests -*- lexical-binding: t -*-
+;;; alloc-tests.el --- alloc tests -*- lexical-binding: t -*-
;; Copyright (C) 2015 Free Software Foundation, Inc.
diff --git a/test/src/decompress-tests.el b/test/src/decompress-tests.el
index c6c084dd69f..1eea673121c 100644
--- a/test/src/decompress-tests.el
+++ b/test/src/decompress-tests.el
@@ -1,4 +1,4 @@
;;; zlib-tests.el --- Test suite for zlib.
;; Copyright (C) 2013-2015 Free Software Foundation, Inc.
@@ -40,6 +40,6 @@
(buffer-string))
"foo\n"))))
-(provide 'zlib-tests)
+(provide 'decompress-tests)
-;;; zlib-tests.el ends here.
+;;; decompress-tests.el ends here.
@@ -1,4 +1,4 @@
-;;; zlib-tests.el --- Test suite for zlib.
+;;; decompress-tests.el --- Test suite for decompress.
;; Copyright (C) 2013-2015 Free Software Foundation, Inc.